@@ -249,11 +249,10 @@ JS
                     progressBar: null,
                     cancelButton: null,
                     component: me.lookup('uploads').add({
-                        layout: {
-                            type: 'hbox',
-                            align: 'center',
-                            pack: 'space-between',
-                        },
+                        layout: 'vbox',
+                        items: [{
+                            html: file.name
+                        }],
                     }),
 
                     cancel: function () {
@@ -280,12 +279,20 @@ JS
                 upload.progressBar.setText(text + ' ' + percent + '%');
             };
 
-            upload.progressBar = upload.component.add({
+            var progressCmp = upload.component.add({
+                layout: {
+                    type: 'hbox',
+                    align: 'center',
+                    pack: 'space-between',
+                },
+            });
+
+            upload.progressBar = progressCmp.add({
                 xtype: 'progress',
                 flex: 1,
             });
 
-            upload.cancelButton = upload.component.add({
+            upload.cancelButton = progressCmp.add({
                 xtype: 'button',
                 iconCls: '$FAS_TIMES',
                 handler: function() {upload.cancel()},
